@@ -29,7 +29,7 @@
 
 using namespace Attica;
 
-class ProviderManager::Private
+class Q_DECL_HIDDEN ProviderManager::Private
 {
 public:
     PlatformDependent *m_internals;
@@ -266,13 +266,6 @@ QList<Provider> ProviderManager::providers() const
     return d->m_providers.values();
 }
 
-#if ATTICA_BUILD_DEPRECATED_SINCE(5, 23)
-bool ProviderManager::contains(const QString &provider) const
-{
-    return d->m_providers.contains(QUrl(provider));
-}
-#endif
-
 QList<QUrl> ProviderManager::providerFiles() const
 {
     return d->m_providerTargets.keys();
@@ -327,3 +320,5 @@ void ProviderManager::initNetworkAccesssManager()
     connect(d->m_internals->nam(), &QNetworkAccessManager::authenticationRequired, this, &ProviderManager::authenticate);
     connect(d->m_internals->nam(), &QNetworkAccessManager::proxyAuthenticationRequired, this, &ProviderManager::proxyAuthenticationRequired);
 }
+
+#include "moc_providermanager.cpp"
